package com.ruoyi.bst.chat.service.impl;

import com.ruoyi.bst.chat.domain.Chat;
import com.ruoyi.bst.chat.domain.ChatVO;
import com.ruoyi.bst.chat.domain.dto.ChatCacheDTO;
import com.ruoyi.bst.chat.service.ChatConverter;
import com.ruoyi.bst.chat.service.ChatService;

import com.ruoyi.bst.chatMsg.domain.ChatMsg;
import com.ruoyi.bst.chatMsg.domain.ChatMsgVO;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.domain.enums.TeamStatus;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.bst.teamUser.service.TeamUserService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class ChatConverterImpl implements ChatConverter {

    @Autowired
    private ChatService chatService;

    @Autowired
    private TeamUserService teamUserService;
    @Autowired
    private TeamService teamService;

    @Override
    public ChatCacheDTO toDTOByCreate(Chat chat) {

        // 拼桌存在校验
        TeamQuery query = new TeamQuery();
        query.setStatus(TeamStatus.NORMAL.getCode());
        query.setId(chat.getTeamId());
        TeamVO vo = teamService.selectOne(query);
        ServiceUtil.assertion(vo==null,"id为%s的拼桌不存在",chat.getTeamId());

        // 获取成员ID列表
        List<Long> userIds = teamUserService.selectUserIdsByTeamId(chat.getTeamId());
        ServiceUtil.assertion(!userIds.contains(chat.getSendId()), "你不是当前群聊的成员,无法发送消息");

        List<ChatMsg> messages = userIds.stream()
                .map(userId -> buildChatMessage(chat,userId))
                .collect(Collectors.toList());

        // 创建缓存DTO 用于定时任务写入
        ChatCacheDTO dto = new ChatCacheDTO();
        dto.setChat(chat);
        dto.setMsgList(messages);
        return dto;
    }

    private ChatMsg buildChatMessage(Chat chat,Long userId) {
        ChatMsg message = new ChatMsg();
        // 生成聊天记录
        message.setChatId(chat.getId());
        message.setUserId(userId);
        return message;
    }
}
