package com.ruoyi.bst.chat.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.chat.domain.dto.ChatCacheDTO;
import com.ruoyi.bst.chat.domain.enums.ChatMsgMethod;
import com.ruoyi.bst.chat.domain.enums.ChatMsgType;
import com.ruoyi.bst.chat.domain.vo.ChatRetractVO;
import com.ruoyi.bst.chat.service.ChatConverter;
import com.ruoyi.bst.chatMsg.domain.ChatMsg;
import com.ruoyi.bst.chatMsg.domain.ChatMsgQuery;
import com.ruoyi.bst.chatMsg.domain.ChatMsgVO;
import com.ruoyi.bst.chatMsg.service.ChatMsgService;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.SnowFlakeUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.user.service.UserService;
import com.ruoyi.ws.service.UserWebSocketService;
import com.sun.org.apache.regexp.internal.RE;
import org.checkerframework.checker.units.qual.C;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.chat.mapper.ChatMapper;
import com.ruoyi.bst.chat.domain.Chat;
import com.ruoyi.bst.chat.domain.ChatVO;
import com.ruoyi.bst.chat.domain.ChatQuery;
import com.ruoyi.bst.chat.service.ChatService;
import org.springframework.transaction.support.TransactionTemplate;

import javax.print.ServiceUI;

/**
 * 聊天记录列表Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-23
 */
@Service
public class ChatServiceImpl implements ChatService {
    @Autowired
    private ChatMapper chatMapper;
    @Autowired
    private ChatConverter chatConverter;
    @Autowired
    private RedisCache redisCache;
    @Autowired
    private UserWebSocketService userWebSocketService;
    @Autowired
    private UserService userService;
    @Autowired
    private TeamService teamService;
    private TransactionTemplate transactionTemplate;
    @Autowired
    private ChatMsgService chatMsgService;

    /**
     * 查询聊天记录列表
     *
     * @param id 聊天记录列表主键
     * @return 聊天记录列表
     */
    @Override
    public ChatVO selectChatById(Long id) {
        return chatMapper.selectChatById(id);
    }

    /**
     * 查询聊天记录列表列表
     *
     * @param chat 聊天记录列表
     * @return 聊天记录列表
     */
    @Override
    public List<ChatVO> selectChatList(ChatQuery chat) {
        return chatMapper.selectChatList(chat);
    }

    /**
     * 新增聊天记录列表
     *
     * @param chat 聊天记录列表
     * @return 结果
     */
    @Override
    public int insertChat(Chat chat) {
        chat.setCreateTime(DateUtils.getNowDate());
        return chatMapper.insertChat(chat);
    }

    /**
     * 修改聊天记录列表
     *
     * @param chat 聊天记录列表
     * @return 结果
     */
    @Override
    public int updateChat(Chat chat) {
        return chatMapper.updateChat(chat);
    }

    /**
     * 批量删除聊天记录列表
     *
     * @param ids 需要删除的聊天记录列表主键
     * @return 结果
     */
    @Override
    public int deleteChatByIds(Long[] ids) {
        return chatMapper.deleteChatByIds(ids);
    }

    /**
     * 删除聊天记录列表信息
     *
     * @param id 聊天记录列表主键
     * @return 结果
     */
    @Override
    public int deleteChatById(Long id) {
        return chatMapper.deleteChatById(id);
    }

    @Override
    public int sendMessage(Chat chat) {
        // 手动设置主表ID
        Long chatId = SnowFlakeUtil.newId();
        chat.setId(chatId);
        // 关联子表
        ChatCacheDTO dto = chatConverter.toDTOByCreate(chat);
        redisCache.rightPush("chat:pending", dto);
        dto.getMsgList().forEach(message -> {
            userWebSocketService.sendMessageToUser(chat, message.getUserId());
        });
        return 1;
    }

    @Override
    public void sendWelcomeMessage(Long teamId, Long userId) {
        // 生成聊天数据
        UserVO user = userService.selectUserById(userId);
        Long chatId = SnowFlakeUtil.newId();
        Chat chat = new Chat();
        chat.setId(chatId);
        chat.setTeamId(teamId);
        chat.setCreateTime(DateUtils.getNowDate());
        chat.setType(ChatMsgType.WELCOME.getCode());
        chat.setContent("欢迎用户" + user.getNickName() + "加入拼桌");

        // 生成聊天消息数据
        ChatMsg message = new ChatMsg();
        message.setChatId(chatId);
        message.setUserId(userId);

        // 生成缓存数据存入redis中
        ChatCacheDTO dto = new ChatCacheDTO();
        dto.setChat(chat);
        dto.setMsgList(Collections.singletonList(message));

        // 向用户发送消息
        redisCache.rightPush("chat:pending",dto);
        userWebSocketService.sendMessageToUser(dto, user.getUserId());
    }

    @Override
    public List<ChatVO> selectTeamMsgList(ChatQuery query) {
        return chatMapper.selectTeamMsgList(query);
    }


    @Override
    public ChatVO selectOne(ChatQuery query) {
        PageHelper.startPage(1, 1);
        List<ChatVO> list = this.selectChatList(query);
        return CollectionUtils.firstElement(list);
    }


    @Override
    public int batchInsert(List<Chat> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return chatMapper.batchInsert(list);
    }


}
