package com.ruoyi.bst.chatMsg.service.impl;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import com.ruoyi.bst.chat.domain.ChatQuery;
import com.ruoyi.bst.chat.domain.ChatVO;
import com.ruoyi.common.domain.vo.LongIntegerVO;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.chatMsg.mapper.ChatMsgMapper;
import com.ruoyi.bst.chatMsg.domain.ChatMsg;
import com.ruoyi.bst.chatMsg.domain.ChatMsgVO;
import com.ruoyi.bst.chatMsg.domain.ChatMsgQuery;
import com.ruoyi.bst.chatMsg.service.ChatMsgService;

/**
 * 聊天消息列表Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-26
 */
@Service
public class ChatMsgServiceImpl implements ChatMsgService
{
    @Autowired
    private ChatMsgMapper chatMsgMapper;

    /**
     * 查询聊天消息列表
     *
     * @param id 聊天消息列表主键
     * @return 聊天消息列表
     */
    @Override
    public ChatMsgVO selectChatMsgById(Long id)
    {
        return chatMsgMapper.selectChatMsgById(id);
    }

    /**
     * 查询聊天消息列表列表
     *
     * @param chatMsg 聊天消息列表
     * @return 聊天消息列表
     */
    @Override
    public List<ChatMsgVO> selectChatMsgList(ChatMsgQuery chatMsg)
    {
        return chatMsgMapper.selectChatMsgList(chatMsg);
    }

    /**
     * 新增聊天消息列表
     *
     * @param chatMsg 聊天消息列表
     * @return 结果
     */
    @Override
    public int insertChatMsg(ChatMsg chatMsg)
    {
        return chatMsgMapper.insertChatMsg(chatMsg);
    }

    /**
     * 修改聊天消息列表
     *
     * @param chatMsg 聊天消息列表
     * @return 结果
     */
    @Override
    public int updateChatMsg(ChatMsg chatMsg)
    {
        return chatMsgMapper.updateChatMsg(chatMsg);
    }

    /**
     * 批量删除聊天消息列表
     *
     * @param ids 需要删除的聊天消息列表主键
     * @return 结果
     */
    @Override
    public int deleteChatMsgByIds(Long[] ids)
    {
        return chatMsgMapper.deleteChatMsgByIds(ids);
    }

    /**
     * 删除聊天消息列表信息
     *
     * @param id 聊天消息列表主键
     * @return 结果
     */
    @Override
    public int deleteChatMsgById(Long id)
    {
        return chatMsgMapper.deleteChatMsgById(id);
    }

    @Override
    public int retractMessage(Long chatId) {
        return chatMsgMapper.retractMessage(chatId);
    }

    @Override
    public int selectCount(ChatMsgQuery query) {
        return chatMsgMapper.selectCount(query);
    }

    // 消息已读
    @Override
    public int read(Long userId, Long chatId) {
        // 两个条件不允许同时为空
        if (chatId == null && userId == null) {
            return 0;
        }
        ChatMsg data = new ChatMsg();
        data.setIsRead(true);
        data.setReadTime(LocalDateTime.now());
        ChatMsgQuery query = new ChatMsgQuery();
        query.setChatId(chatId);
        query.setUserId(userId);
        query.setIsRead(false);
        return chatMsgMapper.updateByQuery(data, query);
    }

    @Override
    public int batchInsert(List<ChatMsg> msgList) {
        if (CollectionUtils.isEmptyElement(msgList)) {
            return 0;
        }
        return chatMsgMapper.batchInsert(msgList);
    }

    @Override
    public List<LongIntegerVO> selectCountGroupByChatId(ChatMsgQuery query) {
        return chatMsgMapper.selectCountGroupByChatId(query);
    }

    @Override
    public List<ChatVO> selectTeamUnReadCount(ChatMsgQuery query) {
        return chatMsgMapper.selectTeamUnReadCount(query);
    }

}
