package com.ruoyi.bst.goods.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.goods.service.GoodsService;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategory;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryQuery;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryVO;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.goods.mapper.GoodsMapper;
import com.ruoyi.bst.goods.domain.Goods;
import com.ruoyi.bst.goods.domain.GoodsVO;
import com.ruoyi.bst.goods.domain.GoodsQuery;

/**
 * 商品Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@Service
public class GoodsServiceImpl implements GoodsService
{
    @Autowired
    private GoodsMapper goodsMapper;

    /**
     * 查询商品
     *
     * @param id 商品主键
     * @return 商品
     */
    @Override
    public GoodsVO selectGoodsById(Long id)
    {
        return goodsMapper.selectGoodsById(id);
    }

    /**
     * 查询商品列表
     *
     * @param goods 商品
     * @return 商品
     */
    @Override
    public List<GoodsVO> selectGoodsList(GoodsQuery goods)
    {
        return goodsMapper.selectGoodsList(goods);
    }

    /**
     * 新增商品
     *
     * @param goods 商品
     * @return 结果
     */
    @Override
    public int insertGoods(Goods goods)
    {
        goods.setCreateTime(DateUtils.getNowDate());
        return goodsMapper.insertGoods(goods);
    }

    /**
     * 修改商品
     *
     * @param goods 商品
     * @return 结果
     */
    @Override
    public int updateGoods(Goods goods)
    {
        return goodsMapper.updateGoods(goods);
    }

    /**
     * 批量删除商品
     *
     * @param ids 需要删除的商品主键
     * @return 结果
     */
    @Override
    public int deleteGoodsByIds(Long[] ids)
    {
        return goodsMapper.deleteGoodsByIds(ids);
    }

    /**
     * 删除商品信息
     *
     * @param id 商品主键
     * @return 结果
     */
    @Override
    public int deleteGoodsById(Long id)
    {
        return goodsMapper.deleteGoodsById(id);
    }

    @Override
    public Goods selectOne(GoodsQuery query) {
        PageHelper.startPage(1, 1);
        List<GoodsVO> notice = this.selectGoodsList(query);
        return CollectionUtils.firstElement(notice);
    }
}
