package com.ruoyi.bst.goodsCategory.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.goods.domain.Goods;
import com.ruoyi.bst.goods.domain.GoodsQuery;
import com.ruoyi.bst.goods.domain.GoodsVO;
import com.ruoyi.bst.goods.service.GoodsService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.notice.domain.Notice;
import com.ruoyi.system.notice.domain.NoticeQuery;
import com.ruoyi.system.notice.domain.NoticeVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.goodsCategory.mapper.GoodsCategoryMapper;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategory;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryVO;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryQuery;
import com.ruoyi.bst.goodsCategory.service.GoodsCategoryService;

/**
 * 商品分类Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@Service
public class GoodsCategoryServiceImpl implements GoodsCategoryService
{
    @Autowired
    private GoodsCategoryMapper goodsCategoryMapper;
    @Autowired
    private GoodsService goodsService;

    /**
     * 查询商品分类
     *
     * @param id 商品分类主键
     * @return 商品分类
     */
    @Override
    public GoodsCategoryVO selectGoodsCategoryById(Long id)
    {
        return goodsCategoryMapper.selectGoodsCategoryById(id);
    }

    /**
     * 查询商品分类列表
     *
     * @param goodsCategory 商品分类
     * @return 商品分类
     */
    @Override
    public List<GoodsCategoryVO> selectGoodsCategoryList(GoodsCategoryQuery goodsCategory)
    {
        return goodsCategoryMapper.selectGoodsCategoryList(goodsCategory);
    }

    /**
     * 新增商品分类
     *
     * @param goodsCategory 商品分类
     * @return 结果
     */
    @Override
    public int insertGoodsCategory(GoodsCategory goodsCategory)
    {
        goodsCategory.setCreateTime(DateUtils.getNowDate());
        if (goodsCategory.getPid()!=null){
            GoodsCategoryVO vo = goodsCategoryMapper.selectGoodsCategoryById(goodsCategory.getPid());
            ServiceUtil.assertion(vo == null ,"id为%s的分类不存在",goodsCategory.getPid());
            ServiceUtil.assertion(vo.getPid()!=null ,"子分类下不允许再创建分类");
        }
        return goodsCategoryMapper.insertGoodsCategory(goodsCategory);
    }

    /**
     * 修改商品分类
     *
     * @param goodsCategory 商品分类
     * @return 结果
     */
    @Override
    public int updateGoodsCategory(GoodsCategory goodsCategory)
    {
        return goodsCategoryMapper.updateGoodsCategory(goodsCategory);
    }

    /**
     * 批量删除商品分类
     *
     * @param ids 需要删除的商品分类主键
     * @return 结果
     */
    @Override
    public int deleteGoodsCategoryByIds(Long[] ids)
    {
        return goodsCategoryMapper.deleteGoodsCategoryByIds(ids);
    }

    /**
     * 删除商品分类信息
     *
     * @param id 商品分类主键
     * @return 结果
     */
    @Override
    public int deleteGoodsCategoryById(Long id)
    {
        GoodsQuery query = new GoodsQuery();
        query.setCategoryId(id);
        Goods goods = goodsService.selectOne(query);
        ServiceUtil.assertion(goods != null,"当前分类下有商品,不允许删除");
        return goodsCategoryMapper.deleteGoodsCategoryById(id);
    }

    @Override
    public GoodsCategory selectOne(GoodsCategoryQuery query) {
            PageHelper.startPage(1, 1);
            List<GoodsCategoryVO> notice = this.selectGoodsCategoryList(query);
            return CollectionUtils.firstElement(notice);
    }
}
