package com.ruoyi.bst.goodsCategory.service.impl;

import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryQuery;
import com.ruoyi.bst.goodsCategory.mapper.GoodsCategoryMapper;
import com.ruoyi.bst.goodsCategory.service.GoodsCategoryValidator;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class GoodsCategoryValidatorImpl implements GoodsCategoryValidator {

    @Autowired
    private GoodsCategoryMapper goodsCategoryMapper;

    @Override
    public boolean canEdit(Long categoryId) {
        return canOperate(Arrays.asList(categoryId));
    }

    // 是否可以操作店铺
    private boolean canOperate(List<Long> categoryIds) {
        return hasPermission(categoryIds, StoreStaffPermission.STORE_EDIT.getCode());
    }

    private boolean hasPermission(List<Long> categoryIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(categoryIds)) {
            return true;
        }
        // 查询运营区
        GoodsCategoryQuery query = new GoodsCategoryQuery();
        query.setCategoryIds(categoryIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> idList = goodsCategoryMapper.selectIdByQuery(query);
        return new HashSet<>(idList).containsAll(categoryIds);
    }

}
