package com.ruoyi.bst.team.service.impl;

import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.service.BoothService;
import com.ruoyi.bst.booth.service.BoothValidator;
import com.ruoyi.bst.store.domain.Store;
import com.ruoyi.bst.store.service.StoreConverter;
import com.ruoyi.bst.team.domain.Team;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.domain.enums.TeamStatus;
import com.ruoyi.bst.team.domain.enums.TeamType;
import com.ruoyi.bst.team.service.TeamConverter;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Date;

@Service
public class TeamConverterImpl implements TeamConverter {

    @Autowired
    private BoothValidator boothValidator;
    @Autowired
    private BoothService boothService;
    @Autowired
    private TeamService teamService;

    @Override
    public Team toPoByCreate(Team data) {
        if (data == null) {
            return null;
        }
        // 设置基本信息
        Team po = new Team();
        if (data.getType().equals(TeamType.BOOK.getCode())){
            ServiceUtil.assertion(data.getBookTime()==null,"预约拼桌时间不可以为空");
            po.setBookTime(data.getBookTime());
        }
        po.setStoreId(data.getStoreId());
        po.setBoothId(data.getBoothId());
        po.setName(data.getName());
        po.setPrefer(data.getPrefer());
        po.setType(data.getType());
        po.setTopic(data.getTopic());
        po.setLimitNum(data.getLimitNum());
        po.setCreateTime(DateUtils.getNowDate());
        po.setStatus(TeamStatus.NORMAL.getCode());
        return po;
    }

    @Override
    public Team toPoByUpdate(Team data) {
        if (data == null) {
            return null;
        }
        // 校验
        ServiceUtil.assertion(data.getId() == null,"拼桌ID不能为空");
        TeamVO team = teamService.selectTeamById(data.getId());
        if (data.getBoothId() != null) {
            BoothVO booth = boothService.selectBoothByBoothId(data.getBoothId());
            ServiceUtil.assertion(!booth.getStoreId().equals(team.getStoreId()),"id为%s的卡座不属于id为%s的店铺",data.getBoothId(),team.getStoreId());
        }
        // 设置基本信息
        Team po = new Team();
        if (data.getType().equals(TeamType.BOOK.getCode())){
            ServiceUtil.assertion(data.getBookTime()==null,"预约拼桌时间不可以为空");
            po.setBookTime(data.getBookTime());
        }
        po.setBoothId(data.getBoothId());
        po.setType(data.getType());
        po.setId(data.getId());
        po.setName(data.getName());
        po.setPrefer(data.getPrefer());
        po.setTopic(data.getTopic());
        po.setLimitNum(data.getLimitNum());
        return po;
    }
}
