package com.ruoyi.bst.team.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.account.domain.AccountQuery;
import com.ruoyi.bst.account.domain.AccountVO;
import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.service.BoothService;
import com.ruoyi.bst.chat.service.ChatService;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.enums.TeamStatus;
import com.ruoyi.bst.team.service.TeamValidator;
import com.ruoyi.bst.teamUser.domain.TeamUser;
import com.ruoyi.bst.teamUser.domain.TeamUserQuery;
import com.ruoyi.bst.teamUser.domain.TeamUserVO;
import com.ruoyi.bst.teamUser.domain.enums.JoinType;
import com.ruoyi.bst.teamUser.domain.enums.RoleType;
import com.ruoyi.bst.teamUser.domain.enums.TeamUserStatus;
import com.ruoyi.bst.teamUser.mapper.TeamUserMapper;
import com.ruoyi.bst.teamUser.service.TeamUserService;
import com.ruoyi.bst.teamUser.service.TeamUserValidator;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.notice.domain.Notice;
import com.ruoyi.system.notice.domain.NoticeQuery;
import com.ruoyi.system.notice.domain.NoticeVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.team.mapper.TeamMapper;
import com.ruoyi.bst.team.domain.Team;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.service.TeamService;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 拼桌Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-22
 */
@Service
public class TeamServiceImpl implements TeamService {
    @Autowired
    private TeamMapper teamMapper;
    @Autowired
    private TransactionTemplate transactionTemplate;
    @Autowired
    private TeamUserService teamUserService;
    @Autowired
    private TeamUserMapper teamUserMapper;
    @Autowired
    private TeamService teamService;
    @Autowired
    private BoothService boothService;
    @Autowired
    private TeamUserValidator teamUserValidator;
    @Autowired
    private TeamValidator teamValidator;
    @Autowired
    private ChatService chatService;

    /**
     * 查询拼桌
     *
     * @param id 拼桌主键
     * @return 拼桌
     */
    @Override
    public TeamVO selectTeamById(Long id, boolean scope) {
        if (id == null) {
            return null;
        }
        TeamQuery query = new TeamQuery();
        query.setId(id);
        query.setScope(scope);
        query.addStorePermission(StoreStaffPermission.TEAM_VIEW.getCode());
        return this.selectOne(query);
    }

    /**
     * 查询拼桌列表
     *
     * @param team 拼桌
     * @return 拼桌
     */
    @Override
    public List<TeamVO> selectTeamList(TeamQuery team) {
        return teamMapper.selectTeamList(team);
    }

    /**
     * 新增拼桌
     *
     * @param team 拼桌
     * @return 结果
     */
    @Override
    public int insertTeam(Team team) {
        team.setCreateTime(DateUtils.getNowDate());
        return teamMapper.insertTeam(team);
    }

    /**
     * 修改拼桌
     *
     * @param team 拼桌
     * @return 结果
     */
    @Override
    public int updateTeam(Team team) {
        if (team.getLimitNum() != null && team.getLimitNum() > 0) {
            TeamVO vo = teamMapper.selectTeamById(team.getId());
            ServiceUtil.assertion(team.getLimitNum() < vo.getCurrentNum(), "当前拼桌人数大于设定的人数,更改失败");
        }
        return teamMapper.updateTeam(team);
    }

    /**
     * 批量删除拼桌
     *
     * @param ids 需要删除的拼桌主键
     * @return 结果
     */
    @Override
    public int deleteTeamByIds(Long[] ids) {
        return teamMapper.deleteTeamByIds(ids);
    }

    /**
     * 删除拼桌信息
     *
     * @param id 拼桌主键
     * @return 结果
     */
    @Override
    public int deleteTeamById(Long id) {
        return teamMapper.deleteTeamById(id);
    }

    @Override
    public int joinTeam(Long teamId, Long userId) {
        TeamUser teamUser = new TeamUser();
        return this.insertTeamUser(teamId, teamUser, userId, RoleType.MEMBERS.getCode(), JoinType.ACTIVE.getCode(), TeamUserStatus.JOINED.getCode());
    }

    @Override
    public int invitedTeam(Long teamId, Long userId, Long inviterId) {
        TeamUser teamUser = new TeamUser();
        teamUser.setInviterId(inviterId);
        return this.insertTeamUser(teamId, teamUser, userId, RoleType.MEMBERS.getCode(), JoinType.INVITED.getCode(), TeamUserStatus.JOINED.getCode());
    }

    @Override
    public int exitTeam(Long teamId, Long userId) {
        return this.exit(teamId, userId,TeamUserStatus.EXITED.getCode());
    }

    @Override
    public int kick(Long teamId, Long userId) {
        return this.exit(teamId, userId,TeamUserStatus.KICKED.getCode());
    }

    public int exit(Long teamId, Long userId ,String userStatus) {
        TeamUserQuery query = new TeamUserQuery();
        query.setTeamId(teamId);
        query.setUserId(userId);
        query.setStatus(TeamUserStatus.JOINED.getCode());
        // 拼桌相关校验
        TeamVO team = teamMapper.selectTeamById(teamId);
        ServiceUtil.assertion(team == null, "id为%s的拼桌信息不存在", teamId);
        TeamUserVO vo = teamUserService.selectOne(query);
        ServiceUtil.assertion(vo == null, "id为%s的用户不属于属于该拼桌的成员",userId);
        // 区分管理员踢出成员还是主动退出
        if (userStatus.equals(TeamUserStatus.EXITED.getCode())) {
            ServiceUtil.assertion(vo.getRole().equals(RoleType.CREATOR.getCode()), "发起者如果要退出请选择解散拼桌");
        }
        vo.setStatus(userStatus);
        Integer result = transactionTemplate.execute(status -> {
            // 更新当前拼桌人数
            int i = teamMapper.reduceCurrentNum(teamId);
            ServiceUtil.assertion(i <= 0, "拼桌人数减少失败");
            // 更新用户状态
            i = teamUserService.updateTeamUser(vo);
            ServiceUtil.assertion(i <= 0, "退出拼桌失败");
            return i;
        });
        return result;
    }

    @Override
    public int disTeam(Long teamId) {
        TeamVO team = teamService.selectTeamById(teamId);
        ServiceUtil.assertion(team == null, "id为%s的拼桌信息不存在", teamId);
        Integer result = transactionTemplate.execute(status -> {
            team.setStatus(TeamStatus.DIS.getCode());
            team.setCurrentNum(0);
            int i = teamService.updateTeam(team);
            ServiceUtil.assertion(i <= 0, "拼桌信息更新失败");
            // 修改对应的用户为解散状态
            TeamUser data = new TeamUser();
            data.setStatus(TeamUserStatus.DISBANDED.getCode());
            TeamUserQuery query = new TeamUserQuery();
            query.setTeamId(teamId);
            i = teamUserMapper.updateByQuery(data,query);
            ServiceUtil.assertion(i <= 0, "解散拼桌失败");
            return i;
        });
        return result;
    }

    @Override
    public TeamVO selectOne(TeamQuery query) {
        PageHelper.startPage(1, 1);
        List<TeamVO> list = this.selectTeamList(query);
        return CollectionUtils.firstElement(list);
    }

    @Override
    public List<TeamUserVO> getTeammate(Long teamId) {
        TeamQuery query = new TeamQuery();
        query.setId(teamId);
        query.setStatus(TeamStatus.NORMAL.getCode());
        TeamVO vo = teamService.selectOne(query);
        ServiceUtil.assertion(vo == null, "id为%s的拼桌不存在或已解散", teamId);
        List<TeamUserVO> list = teamUserService.selectTeamUserListByTeamId(teamId);
        ArrayList<TeamUserVO> userList = new ArrayList<>();
        for (TeamUserVO teamUserVO : list) {
            if (teamUserVO.getStatus().equals(TeamUserStatus.JOINED.getCode())) {
                userList.add(teamUserVO);
            }
        }
        return userList;
    }

    @Override
    public TeamVO getTeamInfo(TeamQuery query) {
        TeamVO vo = teamService.selectOne(query);
        ServiceUtil.assertion(vo == null,"该拼桌不存在或已解散");
        return vo;
    }

    @Override
    public int createTeam(Team team, Long userId) {
        BoothVO booth = boothService.selectBoothByBoothId(team.getBoothId());
        ServiceUtil.assertion(booth == null, "id为%s的卡座不存在", team.getBoothId());
        ServiceUtil.assertion(!booth.getStoreId().equals(team.getStoreId()), "id为%s的卡座不属于id为%s的店铺,发起拼桌失败", booth.getBoothId(), team.getStoreId());
        Integer result = transactionTemplate.execute(status -> {
            int rows = teamMapper.insertTeam(team);
            ServiceUtil.assertion(rows <= 0, "发起拼桌失败");
            TeamUser teamUser = new TeamUser();
            rows = insertTeamUser(team.getId(), teamUser, userId, RoleType.CREATOR.getCode(), JoinType.CREATE.getCode(), TeamUserStatus.JOINED.getCode());
            ServiceUtil.assertion(rows <= 0, "发起拼桌失败");
            return rows;
        });
        return result;
    }

    public int insertTeamUser(Long teamId, TeamUser teamUser, Long userId, String role, String JoinType, String userStatus) {

        ServiceUtil.assertion(!teamUserValidator.canJoinTeam(userId), "您有正在进行的拼桌,请先结束后再进行拼桌");
        ServiceUtil.assertion(!teamValidator.canAddUser(teamId), "当前拼桌不存在或已解散,无法加入");
        TeamVO vo = teamService.selectTeamById(teamId);
        ServiceUtil.assertion(vo == null, "id为%s的拼桌信息不存在", teamId);
        Integer result = transactionTemplate.execute(status -> {

            // 增加当前人数
            int i = teamMapper.addCurrentNums(vo);
            ServiceUtil.assertion(i <= 0, "加入拼桌失败");

            // 插入用户拼桌信息
            teamUser.setTeamId(teamId);
            teamUser.setUserId(userId);
            teamUser.setRole(role);
            teamUser.setJoinType(JoinType);
            teamUser.setStatus(userStatus);
            i = teamUserService.insertTeamUser(teamUser);
            ServiceUtil.assertion(i <= 0, "加入拼桌失败");

            // 向用户发送默认欢迎消息
            chatService.sendWelcomeMessage(teamId,userId);
            return i;
        });
        return result;
    }


}
