package com.ruoyi.bst.team.service.impl;

import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.domain.enums.TeamStatus;
import com.ruoyi.bst.team.mapper.TeamMapper;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.bst.team.service.TeamValidator;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class TeamValidatorImpl implements TeamValidator {

    @Autowired
    private TeamService teamService;
    @Autowired
    private TeamMapper teamMapper;

    @Override
    public boolean canAddUser(Long teamId) {
        TeamQuery query = new TeamQuery();
        query.setId(teamId);
        query.setStatus(TeamStatus.NORMAL.getCode());
        TeamVO vo = teamService.selectOne(query);
        return vo != null;
    }

    @Override
    public boolean canEdit(Long teamId) {
        return canOperate(Arrays.asList(teamId));
    }

    // 是否可以操作拼桌队伍
    private boolean canOperate(List<Long> teamIds) {
        return hasPermission(teamIds, StoreStaffPermission.TEAM_EDIT.getCode());
    }

    private boolean hasPermission(List<Long> teamIds, String permission) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(teamIds)) {
            return true;
        }
        // 查询运营区
        TeamQuery query = new TeamQuery();
        query.setTeamIds(teamIds);
        query.setScope(true);
        query.addStorePermission(permission);
        List<Long> teamIdList = teamMapper.selectIdByQuery(query);
        return new HashSet<>(teamIdList).containsAll(teamIds);
    }
}
