package com.ruoyi.bst.teamUser.service.impl;

import java.util.Collections;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.bst.teamUser.domain.enums.TeamUserStatus;

import com.ruoyi.bst.teamUser.service.TeamUserService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.notice.domain.Notice;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.teamUser.mapper.TeamUserMapper;
import com.ruoyi.bst.teamUser.domain.TeamUser;
import com.ruoyi.bst.teamUser.domain.TeamUserVO;
import com.ruoyi.bst.teamUser.domain.TeamUserQuery;

/**
 * 拼桌用户Service业务层处理
 *
 * @author ruoyi
 * @date 2025-05-22
 */
@Service
public class TeamUserServiceImpl implements TeamUserService
{
    @Autowired
    private TeamUserMapper teamUserMapper;
    @Autowired
    private TeamUserService teamUserService;
    @Autowired
    private TeamService teamService;

    /**
     * 查询拼桌用户
     *
     * @param id 拼桌用户主键
     * @return 拼桌用户
     */
    @Override
    public TeamUserVO selectTeamUserById(Long id)
    {
        return teamUserMapper.selectTeamUserById(id);
    }

    /**
     * 查询拼桌用户列表
     *
     * @param teamUser 拼桌用户
     * @return 拼桌用户
     */
    @Override
    public List<TeamUserVO> selectTeamUserList(TeamUserQuery teamUser)
    {
        return teamUserMapper.selectTeamUserList(teamUser);
    }

    /**
     * 新增拼桌用户
     *
     * @param teamUser 拼桌用户
     * @return 结果
     */
    @Override
    public int insertTeamUser(TeamUser teamUser)
    {
        teamUser.setCreateTime(DateUtils.getNowDate());
        return teamUserMapper.insertTeamUser(teamUser);
    }

    /**
     * 修改拼桌用户
     *
     * @param teamUser 拼桌用户
     * @return 结果
     */
    @Override
    public int updateTeamUser(TeamUser teamUser)
    {
        return teamUserMapper.updateTeamUser(teamUser);
    }

    /**
     * 批量删除拼桌用户
     *
     * @param ids 需要删除的拼桌用户主键
     * @return 结果
     */
    @Override
    public int deleteTeamUserByIds(Long[] ids)
    {
        return teamUserMapper.deleteTeamUserByIds(ids);
    }

    /**
     * 删除拼桌用户信息
     *
     * @param id 拼桌用户主键
     * @return 结果
     */
    @Override
    public int deleteTeamUserById(Long id)
    {
        return teamUserMapper.deleteTeamUserById(id);
    }

    @Override
    public TeamUserVO selectOne(TeamUserQuery query) {
        PageHelper.startPage(1, 1);
        List<TeamUserVO> teamUserList = this.selectTeamUserList(query);
        return CollectionUtils.firstElement(teamUserList);
    }

    @Override
    public List<TeamUserVO> selectTeamUserListByTeamId(Long teamId) {
        return teamUserMapper.selectTeamUserListByTeamId(teamId);
    }

    @Override
    public List<TeamUserVO> selectCurrentNums(TeamUserQuery query) {
        return teamUserMapper.selectCurrentNums(query);
    }

    @Override
    public TeamUserVO selectMyTeam(Long userId) {
        TeamUserQuery query = new TeamUserQuery();
        query.setStatus(TeamUserStatus.JOINED.getCode());
        query.setUserId(userId);
        TeamUserVO teamUserVO = this.selectOne(query);
        if (teamUserVO != null) {
            TeamVO teamVO = teamService.selectTeamById(teamUserVO.getTeamId());
            if (teamVO != null) {
                teamUserVO.setTeam(teamVO);
            }
        }
        return teamUserVO;
    }

    @Override
    public List<Long> selectUserIdsByTeamId(Long teamId) {
        return teamUserMapper.selectUserIdsByTeamId(teamId);
    }

    @Override
    public TeamUserVO getTeamUser(TeamUserQuery query) {
        TeamUserVO vo = this.selectOne(query);
        ServiceUtil.assertion(vo == null,"当前组队成员信息不存在");
        return vo;
    }

    @Override
    public int kick(Long teamId, Long userId) {
        return teamService.kick(teamId, userId);
    }
}
