package com.ruoyi.task.chat;

import com.ruoyi.bst.chat.domain.Chat;
import com.ruoyi.bst.chat.domain.dto.ChatCacheDTO;
import com.ruoyi.bst.chat.service.ChatService;
import com.ruoyi.bst.chatMsg.domain.ChatMsg;
import com.ruoyi.bst.chatMsg.service.ChatMsgService;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.collection.CollectionUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.support.TransactionTemplate;

import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

@Component("chatTask")
@Slf4j
public class ChatTask {

    @Autowired
    private RedisCache redisCache;
    @Autowired
    private ChatService chatService;
    @Autowired
    private TransactionTemplate transactionTemplate;
    @Autowired
    private ChatMsgService chatMsgService;

    public void batchPersist(){
        String pendingKey = "chat:pending";

        List<ChatCacheDTO> cacheList = redisCache.getAndClearCacheList(pendingKey);

        // TODO 批量新增主表
        List<Chat> chatList = CollectionUtils.map(cacheList, ChatCacheDTO::getChat);

        // TODO 获取子表数据，并扁平化
        List<ChatMsg> msgList = cacheList.stream().map(ChatCacheDTO::getMsgList).flatMap(Collection::stream).collect(Collectors.toList());

        // 数据库操作
        transactionTemplate.execute(status -> {
            // 插入主表数据
            chatService.batchInsert(chatList);
            // 插入子表数据
            chatMsgService.batchInsert(msgList);
            return null;
        });
    }
}
