package com.ruoyi.web.app;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.chat.domain.Chat;
import com.ruoyi.bst.chat.domain.ChatQuery;
import com.ruoyi.bst.chat.domain.ChatVO;
import com.ruoyi.bst.chat.domain.enums.ChatMsgType;
import com.ruoyi.bst.chat.mapper.ChatMapper;
import com.ruoyi.bst.chat.service.ChatAssembler;
import com.ruoyi.bst.chat.service.ChatConverter;
import com.ruoyi.bst.chat.service.ChatService;
import com.ruoyi.bst.chatMsg.domain.ChatMsgQuery;
import com.ruoyi.bst.chatMsg.service.ChatMsgService;
import com.ruoyi.bst.commandLog.domain.CommandLog;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.ws.service.UserWebSocketService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Collection;
import java.util.List;
import java.util.Set;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

@RestController
@RequestMapping("/app/chat")
public class AppChatController extends BaseController {

    @Autowired
    private ChatService chatService;
    @Autowired
    private ChatMapper chatMapper;
    @Autowired
    private ChatMsgService chatMsgService;
    @Autowired
    private ChatAssembler chatAssembler;

    @ApiOperation("发送消息")
    @PostMapping("/sendMessage")
    public AjaxResult sendMessage(@RequestBody @Validated(ValidGroup.Create.class) Chat chat) {
        chat.setSendId(getUserId());
        chat.setCreateTime(DateUtils.getNowDate());
        return AjaxResult.success(chatService.sendMessage(chat));
    }

    @ApiOperation("消息已读，id为空时，则将本人所有未读消息设置为已读")
    @PostMapping("/read")
    public AjaxResult read(@RequestParam(required = false) Long chatId) {
        return AjaxResult.success(chatMsgService.read(getUserId(), chatId));
    }

    @ApiOperation("获取队伍聊天消息列表")
    @GetMapping("/receiveList")
    public TableDataInfo receiveList(ChatQuery query) {
        startPage();
        PageHelper.orderBy("create_time desc");
        query.setDeleted(false);
        List<ChatVO> list = chatService.selectChatList(query);
        return getDataTable(list);
    }

    @ApiOperation("获取拼桌未读消息列表")
    @GetMapping("/teamMsgRecord")
    public TableDataInfo teamMsgRecord(ChatMsgQuery query) {
        startPage();
        query.setDeleted(false);
        query.setUserId(getUserId());
        List<ChatVO> list = chatMsgService.selectTeamUnReadCount(query);
        return getDataTable(list);
    }

    @ApiOperation("查询本人未读消息数量")
    @GetMapping("/unreadCount")
    public AjaxResult unreadCount() {
        ChatMsgQuery query = new ChatMsgQuery();
        query.setUserId(getUserId());
        query.setIsRead(false);
        return AjaxResult.success(chatMsgService.selectCount(query));
    }

    @ApiOperation("撤回消息")
    @PostMapping("/retractMessage")
    public AjaxResult retractMessage(@RequestParam Long chatId) {
        ChatVO vo = chatService.selectChatById(chatId);
        if (!getUserId().equals(vo.getSendId())) {
            return error("您无权撤回当前消息");
        }
        return AjaxResult.success(chatMsgService.retractMessage(chatId));
    }

}
