package com.ruoyi.web.bst;

import com.ruoyi.bst.chat.domain.Chat;
import com.ruoyi.bst.chat.domain.ChatQuery;
import com.ruoyi.bst.chat.domain.ChatVO;
import com.ruoyi.bst.chat.service.ChatService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 聊天记录列表Controller
 *
 * @author ruoyi
 * @date 2025-05-23
 */
@RestController
@RequestMapping("/bst/chat")
public class ChatController extends BaseController
{
    @Autowired
    private ChatService chatService;

    /**
     * 查询聊天记录列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:list')")
    @GetMapping("/list")
    public TableDataInfo list(ChatQuery query)
    {
        startPage();
        startOrderBy();
        List<ChatVO> list = chatService.selectChatList(query);
        return getDataTable(list);
    }

    /**
     * 导出聊天记录列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:export')")
    @Log(title = "聊天记录列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ChatQuery query)
    {
        List<ChatVO> list = chatService.selectChatList(query);
        ExcelUtil<ChatVO> util = new ExcelUtil<ChatVO>(ChatVO.class);
        util.exportExcel(response, list, "聊天记录列表数据");
    }

    /**
     * 获取聊天记录列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(chatService.selectChatById(id));
    }

    /**
     * 新增聊天记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:add')")
    @Log(title = "聊天记录列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Chat chat)
    {
        return toAjax(chatService.insertChat(chat));
    }

    /**
     * 修改聊天记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:edit')")
    @Log(title = "聊天记录列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Chat chat)
    {
        return toAjax(chatService.updateChat(chat));
    }

    /**
     * 删除聊天记录列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chat:remove')")
    @Log(title = "聊天记录列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(chatService.deleteChatByIds(ids));
    }
}
