package com.ruoyi.web.bst;

import com.ruoyi.bst.chatMsg.domain.ChatMsg;
import com.ruoyi.bst.chatMsg.domain.ChatMsgQuery;
import com.ruoyi.bst.chatMsg.domain.ChatMsgVO;
import com.ruoyi.bst.chatMsg.service.ChatMsgService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 聊天消息列表Controller
 *
 * @author ruoyi
 * @date 2025-05-26
 */
@RestController
@RequestMapping("/bst/chatMsg")
public class ChatMsgController extends BaseController
{
    @Autowired
    private ChatMsgService chatMsgService;

    /**
     * 查询聊天消息列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:list')")
    @GetMapping("/list")
    public TableDataInfo list(ChatMsgQuery query)
    {
        startPage();
        startOrderBy();
        List<ChatMsgVO> list = chatMsgService.selectChatMsgList(query);
        return getDataTable(list);
    }

    /**
     * 导出聊天消息列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:export')")
    @Log(title = "聊天消息列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ChatMsgQuery query)
    {
        List<ChatMsgVO> list = chatMsgService.selectChatMsgList(query);
        ExcelUtil<ChatMsgVO> util = new ExcelUtil<ChatMsgVO>(ChatMsgVO.class);
        util.exportExcel(response, list, "聊天消息列表数据");
    }

    /**
     * 获取聊天消息列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(chatMsgService.selectChatMsgById(id));
    }

    /**
     * 新增聊天消息列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:add')")
    @Log(title = "聊天消息列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ChatMsg chatMsg)
    {
        return toAjax(chatMsgService.insertChatMsg(chatMsg));
    }

    /**
     * 修改聊天消息列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:edit')")
    @Log(title = "聊天消息列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ChatMsg chatMsg)
    {
        return toAjax(chatMsgService.updateChatMsg(chatMsg));
    }

    /**
     * 删除聊天消息列表
     */
    @PreAuthorize("@ss.hasPermi('bst:chatMsg:remove')")
    @Log(title = "聊天消息列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(chatMsgService.deleteChatMsgByIds(ids));
    }
}
