package com.ruoyi.web.bst;

import com.ruoyi.bst.goodsCategory.domain.GoodsCategory;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryQuery;
import com.ruoyi.bst.goodsCategory.domain.GoodsCategoryVO;
import com.ruoyi.bst.goodsCategory.service.GoodsCategoryService;
import com.ruoyi.bst.goodsCategory.service.GoodsCategoryValidator;
import com.ruoyi.bst.store.service.StoreValidator;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商品分类Controller
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/bst/goodsCategory")
public class GoodsCategoryController extends BaseController
{
    @Autowired
    private GoodsCategoryService goodsCategoryService;
    @Autowired
    private GoodsCategoryValidator goodsCategoryValidator;
    @Autowired
    private StoreValidator storeValidator;

    /**
     * 查询商品分类列表
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:list')")
    @GetMapping("/list")
    public TableDataInfo list(GoodsCategoryQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        List<GoodsCategoryVO> list = goodsCategoryService.selectGoodsCategoryList(query);
        return getDataTable(list);
    }

    /**
     * 导出商品分类列表
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:export')")
    @Log(title = "商品分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GoodsCategoryQuery query)
    {
        List<GoodsCategoryVO> list = goodsCategoryService.selectGoodsCategoryList(query);
        ExcelUtil<GoodsCategoryVO> util = new ExcelUtil<GoodsCategoryVO>(GoodsCategoryVO.class);
        util.exportExcel(response, list, "商品分类数据");
    }

    /**
     * 获取商品分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(goodsCategoryService.selectGoodsCategoryById(id));
    }

    /**
     * 新增商品分类
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:add')")
    @Log(title = "商品分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GoodsCategory goodsCategory)
    {
        if (!storeValidator.canEdit(goodsCategory.getStoreId())) {
            return error("您无权限修改该店铺相关信息");
        }
        return toAjax(goodsCategoryService.insertGoodsCategory(goodsCategory));
    }

    /**
     * 修改商品分类
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:edit')")
    @Log(title = "商品分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GoodsCategory goodsCategory)
    {
        if (!goodsCategoryValidator.canEdit(goodsCategory.getId())) {
            return error("您无权限修改当前分类信息");
        }
        return toAjax(goodsCategoryService.updateGoodsCategory(goodsCategory));
    }

    /**
     * 删除商品分类
     */
    @PreAuthorize("@ss.hasPermi('bst:goodsCategory:remove')")
    @Log(title = "商品分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Long id)
    {
        return toAjax(goodsCategoryService.deleteGoodsCategoryById(id));
    }
}
