package com.ruoyi.web.bst;

import com.ruoyi.bst.spec.domain.Spec;
import com.ruoyi.bst.spec.domain.SpecQuery;
import com.ruoyi.bst.spec.domain.SpecVO;
import com.ruoyi.bst.spec.service.SpecService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商品规格项Controller
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/bst/spec")
public class SpecController extends BaseController
{
    @Autowired
    private SpecService specService;

    /**
     * 查询商品规格项列表
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:list')")
    @GetMapping("/list")
    public TableDataInfo list(SpecQuery query)
    {
        startPage();
        startOrderBy();
        List<SpecVO> list = specService.selectSpecList(query);
        return getDataTable(list);
    }

    /**
     * 导出商品规格项列表
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:export')")
    @Log(title = "商品规格项", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SpecQuery query)
    {
        List<SpecVO> list = specService.selectSpecList(query);
        ExcelUtil<SpecVO> util = new ExcelUtil<SpecVO>(SpecVO.class);
        util.exportExcel(response, list, "商品规格项数据");
    }

    /**
     * 获取商品规格项详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(specService.selectSpecById(id));
    }

    /**
     * 新增商品规格项
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:add')")
    @Log(title = "商品规格项", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Spec spec)
    {
        return toAjax(specService.insertSpec(spec));
    }

    /**
     * 修改商品规格项
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:edit')")
    @Log(title = "商品规格项", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Spec spec)
    {
        return toAjax(specService.updateSpec(spec));
    }

    /**
     * 删除商品规格项
     */
    @PreAuthorize("@ss.hasPermi('bst:spec:remove')")
    @Log(title = "商品规格项", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(specService.deleteSpecByIds(ids));
    }
}
