package com.ruoyi.web.bst;

import com.ruoyi.bst.specValue.domain.SpecValue;
import com.ruoyi.bst.specValue.domain.SpecValueQuery;
import com.ruoyi.bst.specValue.domain.SpecValueVO;
import com.ruoyi.bst.specValue.service.SpecValueService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商品规格值Controller
 *
 * @author ruoyi
 * @date 2025-05-28
 */
@RestController
@RequestMapping("/bst/specValue")
public class SpecValueController extends BaseController
{
    @Autowired
    private SpecValueService specValueService;

    /**
     * 查询商品规格值列表
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:list')")
    @GetMapping("/list")
    public TableDataInfo list(SpecValueQuery query)
    {
        startPage();
        startOrderBy();
        List<SpecValueVO> list = specValueService.selectSpecValueList(query);
        return getDataTable(list);
    }

    /**
     * 导出商品规格值列表
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:export')")
    @Log(title = "商品规格值", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SpecValueQuery query)
    {
        List<SpecValueVO> list = specValueService.selectSpecValueList(query);
        ExcelUtil<SpecValueVO> util = new ExcelUtil<SpecValueVO>(SpecValueVO.class);
        util.exportExcel(response, list, "商品规格值数据");
    }

    /**
     * 获取商品规格值详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(specValueService.selectSpecValueById(id));
    }

    /**
     * 新增商品规格值
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:add')")
    @Log(title = "商品规格值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SpecValue specValue)
    {
        return toAjax(specValueService.insertSpecValue(specValue));
    }

    /**
     * 修改商品规格值
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:edit')")
    @Log(title = "商品规格值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SpecValue specValue)
    {
        return toAjax(specValueService.updateSpecValue(specValue));
    }

    /**
     * 删除商品规格值
     */
    @PreAuthorize("@ss.hasPermi('bst:specValue:remove')")
    @Log(title = "商品规格值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(specValueService.deleteSpecValueByIds(ids));
    }
}
