package com.ruoyi.web.bst;

import com.ruoyi.bst.storeStaff.domain.enums.StoreStaffPermission;
import com.ruoyi.bst.team.domain.Team;
import com.ruoyi.bst.team.domain.TeamQuery;
import com.ruoyi.bst.team.domain.TeamVO;
import com.ruoyi.bst.team.service.TeamAssembler;
import com.ruoyi.bst.team.service.TeamConverter;
import com.ruoyi.bst.team.service.TeamService;
import com.ruoyi.bst.team.service.TeamValidator;
import com.ruoyi.bst.teamUser.domain.TeamUserQuery;
import com.ruoyi.bst.teamUser.domain.TeamUserVO;
import com.ruoyi.bst.teamUser.domain.enums.RoleType;
import com.ruoyi.bst.teamUser.service.TeamUserAssembler;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.Collections;
import java.util.List;

/**
 * 拼桌Controller
 *
 * @author ruoyi
 * @date 2025-05-22
 */
@RestController
@RequestMapping("/bst/team")
public class TeamController extends BaseController
{
    @Autowired
    private TeamService teamService;
    @Autowired
    private TeamUserAssembler teamUserAssembler;
    @Autowired
    private TeamAssembler teamAssembler;
    @Autowired
    private TeamConverter teamConverter;
    @Autowired
    private TeamValidator teamValidator;

    /**
     * 查询拼桌列表
     */
    @PreAuthorize("@ss.hasPermi('bst:team:list')")
    @GetMapping("/list")
    public TableDataInfo list(TeamQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        query.addStorePermission(StoreStaffPermission.TEAM_VIEW.getCode());
        List<TeamVO> list = teamService.selectTeamList(query);
        teamAssembler.assembleSponsor(list);
        return getDataTable(list);
    }

    /**
     * 导出拼桌列表
     */
    @PreAuthorize("@ss.hasPermi('bst:team:export')")
    @Log(title = "拼桌", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TeamQuery query)
    {
        query.setScope(true);
        List<TeamVO> list = teamService.selectTeamList(query);
        ExcelUtil<TeamVO> util = new ExcelUtil<TeamVO>(TeamVO.class);
        util.exportExcel(response, list, "拼桌数据");
    }

    /**
     * 获取拼桌详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:team:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        TeamVO vo = teamService.selectTeamById(id, true);
        teamAssembler.assembleSponsor(Collections.singletonList(vo));
        return success(vo);

    }

    /**
     * 新增拼桌
     */
    @PreAuthorize("@ss.hasPermi('bst:team:add')")
    @Log(title = "拼桌", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Team team)
    {
        Team po = teamConverter.toPoByCreate(team);
        return toAjax(teamService.insertTeam(po));
    }

    /**
     * 修改拼桌
     */
    @PreAuthorize("@ss.hasPermi('bst:team:edit')")
    @Log(title = "拼桌", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Team team)
    {
        if (!teamValidator.canEdit(team.getId())) {
            return AjaxResult.error("您没有权限修改ID为" + team.getId() + "的拼桌信息");
        }
        Team po = teamConverter.toPoByUpdate(team);
        return toAjax(teamService.updateTeam(po));
    }

    /**
     * 删除拼桌
     */
    @PreAuthorize("@ss.hasPermi('bst:team:remove')")
    @Log(title = "拼桌", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(teamService.deleteTeamByIds(ids));
    }


    @PreAuthorize("@ss.hasPermi('bst:team:forcedDis')")
    @Log(title = "强制解散队伍", businessType = BusinessType.OTHER)
    @PutMapping("/forcedDis")
    public AjaxResult forcedDis(@RequestParam Long teamId) {
        return toAjax(teamService.disTeam(teamId));
    }
}
